# anaspro

anaspro is a Python library for generating random user data. It uses Faker to generate usernames, passwords, emails, and phone numbers with country codes based on provided JSON data.

## Installation

You can install anaspro using pip:

```bash
pip install anaspro

